# -*- coding: utf-8 -*-
"""
Metadata.
"""

__title__ = "sweetrpg-catalog-objects"
__description__ = "Model objects for SweetRPG Catalog"
__url__ = "https://sweetrpg.com"
__version__ = "0.0.125"
__build__ = 0x000001
__author__ = "Paul Schifferer"
__author_email__ = "dm@sweetrpg.com"
__license__ = "MIT"
__copyright__ = "Copyright 2023 SweetRPG"
__cake__ = "\u2728 \U0001f370 \u2728"
